#!/usr/bin/env python3
# Copyright (C) 2025 Spearhead Systems SRL

from cmk.rulesets.v1.form_specs.validators import LengthInRange, NumberInRange
from cmk.rulesets.v1.form_specs import Dictionary, DictElement, List, String, Integer, DefaultValue
from cmk.rulesets.v1.rule_specs import SpecialAgent, Topic, Title, Help


def _formspec():
    return Dictionary(
        title=Title("Domains Expiry"),
        elements={
            "domains": DictElement(
                required=True,
                parameter_form=List(
                    title=Title("Domain names"),
                    help_text=Help("List of domain names to check"),
                    editable_order=False,
                    custom_validate=(LengthInRange(min_value=1),),
                    element_template=String(
                        custom_validate=(LengthInRange(min_value=3),),
                    ),
                ),
            ),
            "days_warn": DictElement(
                required=True,
                parameter_form=Integer(
                    title=Title("Warn if expires within days"),
                    help_text=Help("If there are fewer days until one of the above domains expires, issue an alert"),
                    custom_validate=(NumberInRange(min_value=0),),
                    prefill=DefaultValue(30),
                ),
            ),
            "days_crit": DictElement(
                required=True,
                parameter_form=Integer(
                    title=Title("Crit if expires within days"),
                    help_text=Help("If there are fewer days until one of the above domains expires, issue an alert"),
                    custom_validate=(NumberInRange(min_value=0),),
                    prefill=DefaultValue(7),
                ),
            ),
        }
    )


rule_spec_agent_config_domains_expiry = SpecialAgent(
    topic=Topic.NETWORKING,
    name="domains_expiry",
    title=Title("Domains Expiry"),
    parameter_form=_formspec,
)
